#version 330 core

#ifdef GL_ES
precision mediump float;
#endif

in  vec2 v_texCoords;

uniform sampler2D u_texture;
uniform sampler2D u_mask;
uniform sampler2D u_light;
uniform vec2      u_feetPos;
uniform vec2      u_resolution;
uniform int       u_flashing;

out vec4 fragColor;

void main() {
    vec4 texColor   = texture(u_texture, v_texCoords);
    vec2 screenUV   = gl_FragCoord.xy / u_resolution;

    vec4 maskVal    = texture(u_mask,  screenUV);
    vec4 lightVal   = texture(u_light, screenUV);
    vec4 lightAtFeet = texture(u_light, u_feetPos);

    if (maskVal.r == 1.0 || texColor.a < 0.05) {
        discard;
    }

    if (u_flashing == 1) {
        fragColor = vec4(1.0, 1.0, 1.0, texColor.a);
        return;
    }

    if (u_feetPos == vec2(-1.0)) {
        float lightIntensity = max(max(lightVal.r,lightVal.g), lightVal.b);

        fragColor = vec4(texColor.rgb * lightVal.rgb, texColor.a);
    }
    else {
        float lightIntensity = max(max(lightAtFeet.r, lightAtFeet.g), lightAtFeet.b);
        if (lightIntensity < 0.1) {
            discard;
            fragColor = vec4(texColor.rgb * lightAtFeet.rgb, lightIntensity);
        }
        else {
            fragColor = vec4(texColor.rgb * lightAtFeet.rgb, texColor.a);
        }
    }
}
